splitter

package
v0.0.0-...-faed539 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 1, 2021 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Split

func Split(s string, size int) []string

Split splits given string into chunks of given size only at whitespace. If a word is longer than given size, the word is broken up into two or more pieces.

Types

This section is empty.

Jump to